@@ -47,13 +47,13 @@ class kpColorSimilarityDialog : public QDialog
 Q_OBJECT
 
 public:
-    kpColorSimilarityDialog (QWidget *parent);
+    explicit kpColorSimilarityDialog (QWidget *parent);
     ~kpColorSimilarityDialog () override;
 
     double colorSimilarity () const;
     void setColorSimilarity (double similarity);
 
-private slots:
+private Q_SLOTS:
     void slotColorSimilarityValueChanged ();
 
     void slotWhatIsLabelClicked ();
