@@ -102,11 +102,7 @@ protected:
     void mouseMoveEvent (QMouseEvent *e) override;
     void mouseReleaseEvent (QMouseEvent *e) override;
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     void enterEvent (QEnterEvent *e) override;
-#else
-    void enterEvent (QEvent *e) override;
-#endif
     void leaveEvent (QEvent *e) override;
 
 protected:
